OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard app",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Start din dag informeret\n\nNextcloud Dashboard er dit udgangspunkt på dagen og giver dig en\noversigt over dine kommende aftaler, hastemails, chatbeskeder,\nindgående billetter, seneste tweets og meget mere! Brugere kan tilføje widgets\nde kan lide og ændre baggrunden efter deres smag.",
    "Customize" : "Tilpas",
    "Edit widgets" : "Redigér widgets",
    "Get more widgets from the App Store" : "Få flere widgets fra App Store",
    "Change background image" : "Ændre baggrund",
    "Weather service" : "Vejret",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Af hensyn til dit privatliv, er det din Nextcloud-server der henter vejr-data og udbyderen modtager således ingen oplysninger om dig.",
    "Weather data from Met.no" : "Vejr-data leveres af Met.no",
    "geocoding with Nominatim" : "Geocoding med Nominatim",
    "elevation data from OpenTopoData" : "Højde-data fra OpenTopoData",
    "Weather" : "Vejr",
    "Status" : "Status",
    "Good morning" : "God morgen",
    "Good morning, {name}" : "God morgen {name}",
    "Good afternoon" : "God eftermiddag",
    "Good afternoon, {name}" : "God eftermiddag {name}",
    "Good evening" : "God aften",
    "Good evening, {name}" : "God aften {name}",
    "Hello" : "Hej",
    "Hello, {name}" : "Hej {name}",
    "Pick from Files" : "Vælg fra Filer",
    "Default image" : "Standardbillede",
    "Plain background" : "Standard baggrund",
    "Insert from {productName}" : "Indsæt fra {productName}",
    "Show something" : "Vis noget",
    "Default images" : "Standardbilleder"
},
"nplurals=2; plural=(n != 1);");
